--- mmpolar.m	2015-06-01 16:54:21.209618829 -0400
+++ mmpolar_patched.m	2015-06-01 17:04:28.839929220 -0400
@@ -98,6 +98,13 @@
 % 2005-04-25, 2006-01-18, 2006-04-06, 2006-05-17, 2006-05-18
 % 2006-10-03, 2007-03-04, 2008-03-18
 
+% Edited by Dennis Ogbe, dogbe@purdue.edu
+% Added two properties to control the tick label colors independently from
+% the grid line colors:
+%
+% TTickLabelColor    {k} colorspec for theta axis tick labels
+% RTickLabenColor    {k} colorspec for rho axis tick labels
+
 %--------------------------------------------------------------------------
 % Parse Inputs                                                 Parse Inputs
 %--------------------------------------------------------------------------
@@ -471,7 +478,6 @@
       [istrue,cs]=local_iscolorspec(S.RGridColor);
       if istrue
          set(D.HRGrid,'Color',cs)
-         set(D.HRTickLabel,'Color',cs)
          P.RGridColor=cs;
       else
          local_error('Unknown ''RGridColor'' Property Value.')
@@ -560,6 +566,14 @@
       else
          local_error('Unknown ''RTickLabel'' Property Value.')
       end
+   case 'RTickLabelColor'                               % RTickLabelColor
+      [istrue,cs]=local_iscolorspec(S.RTickLabelColor);
+      if istrue
+         set(D.HRTickLabel,'Color',cs)
+         P.RTickLabelColor=cs;
+      else
+         local_error('Unknown ''RTickLabelColor'' Property Value.')
+      end
    case 'RTickLabelHalign'                               % RTickLabelHalign
       fnames={'left' 'center' 'right'};
       out=local_isfield(fnames,S.RTickLabelHalign);
@@ -678,7 +692,6 @@
       [istrue,cs]=local_iscolorspec(S.TGridColor);
       if istrue
          set(D.HTGrid,'Color',cs)
-         set(D.HTTickLabel,'Color',cs)
          P.TGridColor=cs;
       else
          local_error('Unknown ''TGridColor'' Property Value.')
@@ -793,6 +806,14 @@
       else
          local_error('Unknown ''TTickLabel'' Property Value.')
       end
+   case 'TTickLabelColor'                               % TTickLabelColor
+      [istrue,cs]=local_iscolorspec(S.TTickLabelColor);
+      if istrue
+         set(D.HTTickLabel,'Color',cs)
+         P.TTickLabelColor=cs;
+      else
+         local_error('Unknown ''TTickLabelColor'' Property Value.')
+      end
    case 'TTickLabelVisible'                             % TTickLabelVisible
       [istrue,onoff]=local_isonoff(S.TTickLabelVisible);
       if istrue
@@ -1080,7 +1101,7 @@
    end
    D.HRTickLabel(k)=text(xdata,ydata,P.RTickLabel{k},...
       'Parent',HAxes,...
-      'Color',P.TGridColor,...
+      'Color',P.RTickLabelColor,...
       'FontName',P.FontName,...
       'FontSize',P.FontSize,...
       'FontWeight',P.FontWeight',...
@@ -1215,7 +1236,7 @@
    end
    D.HTTickLabel(k)=text(xdata,ydata,P.TTickLabel{k},...
       'Parent',HAxes,...
-      'Color',P.TGridColor,...
+      'Color',P.TTickLabelColor,...
       'FontName',P.FontName,...
       'FontSize',P.FontSize,...
       'FontWeight',P.FontWeight',...
@@ -1291,6 +1312,7 @@
 out.RTickAngle=0;
 out.RTickOffset=0.04;
 out.RTickLabel='0|0.5|1.0';
+out.RTickLabelColor=get(0,'defaultaxesxcolor');
 out.RTickLabelHalign='center';
 out.RTickLabelValign='middle';
 out.RTickLabelVisible='on';
@@ -1305,6 +1327,7 @@
 out.TTickDelta=15;
 out.TTickDirection='in';
 out.TTickLabel='';
+out.TTickLabelColor=get(0,'defaultaxesxcolor');
 out.TTickLabelVisible='on';
 out.TTickSign='+-';
 out.TTickValue=0:15:359;
